@@ -61,9 +61,13 @@
 
 #ifdef __SIM_SSE3
 
+#ifdef __x86_64__
 #include <xmmintrin.h>
 #include <pmmintrin.h>
-  
+#elif __aarch64__
+#include "sse2neon.h"
+#endif
+
 #endif
 
 #ifdef __AVX
